<?php
/**
 * Theme Customizer Settings
 *
 * @package     Relic EDD Store
 * @author     	themerelic
 * @copyright   Copyright (c) 2019, themerelic
 * @link        http://themerelic.com
 * @since       Relic EDD Store 1.0.0
 * */
 /**
  * Customizer file section
  * @since 1.0.0
  */
  class RelicEddStoreCustomizer{

        /**
         * Instance
         *
         * @var $instance
         * @since 1.0.0
         */
        private static $instance;

        /**
         * Initiator
         *
         * @since 1.0.0
         * @return object
         */
        public static function get_instance() {
            if ( ! isset( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }
        
        /**
         * Edd Store Customizer construct functins
         *
         * @access public
         */
        public function __construct(){

            /**
             * Edd Store Customizer panel call
             *
             * @access public
             * @var    array
             * @since 1.0.0
             */
            $relic_edd_store_panels   = array( 'general','home');
        

            /**
             * Edd Store Customizer section array
             *
             * @access public
             * @var    array
             * @since 1.0.0
             */
            $homepage_customizer = array('slider','latest-products','theme-category-section','news-letters','theme-popular-latest-onsell','featured-products','sort');
           


            $relic_edd_store_sub_sections   = array( 
                'general'    => array( 'basic','breadcrumb','archive'),
                'home'       => $homepage_customizer
            );
            
            //call the functions
            $this->relic_edd_store_customizer_panel( $relic_edd_store_panels , $relic_edd_store_sub_sections );


            
            /**
             * Sanitize callback for checkbox
             * 
             * sanitization-functions.php | senitization the custoizer function
             * 
             * @since 1.0.0
            */
            load_template(  RELIC_EDD_STORE_THEME_DIR . 'themerelic/customizer/sanitization-functions.php');
            
            
            /**
             * Customizer Preview Js
             * 
             * 
             * @since 1.0.0
            */
            add_action( 'customize_preview_init',array( $this,'relic_edd_store_customize_preview_js' )  );
            add_action( 'customize_controls_enqueue_scripts',array( $this,'relic_edd_store_customizer_scripts' ) );

        }


        /**
         * Edd Store Customizer load the all panel and section
         *
         * @access public
         * @since 1.0.0
         */
        public function relic_edd_store_customizer_panel( $relic_edd_store_panels , $relic_edd_store_sub_sections ){
            /**
             * Call the panel 
             * 
             * Register the all edd store customizer panel
             * 
             * @since 1.0.0
             */
            foreach( $relic_edd_store_panels as $panel ){
                load_template(  RELIC_EDD_STORE_THEME_DIR . '/themerelic/customizer/panels/' . $panel . '.php');
            }

            
            /**
             * Call the section
             * 
             * Register the all edd store customizer section,
             * and conrol.
             * 
             * @since 1.0.0
             */
            foreach( $relic_edd_store_sub_sections as $k => $v ){
                foreach( $v as $w ){        
                    load_template(  RELIC_EDD_STORE_THEME_DIR . 'themerelic/customizer/panels/' . $k . '/' . $w . '.php');
                }
            }
        }


        
        /**
         * Basic Js File enqueue Section
         * 
         * @access public 
         * @since 1.0.0
         */
        public function relic_edd_store_customize_preview_js() {
            wp_enqueue_style( 'edd-store-customizer-preview', RELIC_EDD_STORE_THEME_URI . 'themerelic/customizer/css/customizer.css', array(), RELIC_EDD_STORE_THEME_VERSION );
            wp_enqueue_script( 'edd-store-customizer-preview', RELIC_EDD_STORE_THEME_URI . 'themerelic/customizer/js/customizer.js', array( 'customize-preview', 'customize-selective-refresh' ), RELIC_EDD_STORE_THEME_VERSION, true );
        }


        /**
         * Basic Js File enqueue Section
         *
         * @access public
         * @since 1.0.0
         */
        public function relic_edd_store_customizer_scripts() {
            wp_enqueue_style( 'edd-store-customize',RELIC_EDD_STORE_THEME_URI.'themerelic/customizer/css/customize.css', RELIC_EDD_STORE_THEME_VERSION, 'screen' );
            wp_enqueue_script( 'edd-store-customize', RELIC_EDD_STORE_THEME_URI . 'themerelic/customizer/js/customize-homepage.js', array( 'jquery' ), RELIC_EDD_STORE_THEME_VERSION, true );
        }
}

/**
 * customizer file this off by calling 'get_instance()' method
 */
RelicEddStoreCustomizer::get_instance();